# -*-coding:utf-8 -*- #
# ---------------------------------------------------------------------------
# ProjectName:   python-learn
# FileName:      read_excel.py
# Author:       xxxxxxx
# Datetime:     2023/8/7 19:07
# Description:
# 
# ---------------------------------------------------------------------------
import openpyxl

from My_APIAuto_demo.common.read_ini import ReadIni
from My_APIAuto_demo.common.read_json import read_json
from My_APIAuto_demo.data_config.settings import *


class ReadExcel:
    def __init__(self):
        self.read_ini = ReadIni()

        case_data_path = self.read_ini.get_file_path(CASE)
        expect_data_path = self.read_ini.get_file_path(EXPECT)
        sql_data_path = self.read_ini.get_file_path(SQL)

        self.case_data_dict = read_json(case_data_path)
        self.expect_data_dict = read_json(expect_data_path)
        self.sql_data_dict = read_json(sql_data_path)

        excel_path = self.read_ini.get_file_path(EXCEL)
        wb = openpyxl.load_workbook(excel_path)
        table_name = self.read_ini.get_table_name(TABLE)
        self.ws = wb[table_name]


    def __get_cell_data(self,column:str,row:int):
        value = self.ws[column + str(row)].value
        if value is None:
            return None
        elif value.strip():
            return value.strip()
        else:
            return None


    def module_name(self,row):
        return self.__get_cell_data(MODULE,row)


    def interface_name(self,row):
        return self.__get_cell_data(API,row)

    def case_title(self,row):
        return self.__get_cell_data(TITLE,row)


    def case_level(self,row):
        return self.__get_cell_data(LEVEL,row)


    def case_method(self,row):
        return self.__get_cell_data(METHOD,row)


    def case_url(self,row):
        host = self.read_ini.get_host(HOST)
        url_name = self.__get_cell_data(PATH,row)
        return host+url_name


    def case_mime(self,row):
        value = self.__get_cell_data(MIME,row)
        if value is None:
            return None
        elif value:
            return value.lower()
        else:
            return None


    def case_data(self,row):
        value = self.__get_cell_data(CASEDATA,row)
        if value is None:
            return None
        elif value:
            module_name = self.module_name(row)
            interface_name = self.interface_name(row)
            return self.case_data_dict[module_name][interface_name][value]
        else:
            return None


    def expect_data(self,row):
        value = self.__get_cell_data(EXPECTDATA,row)
        if value is None:
            return None
        elif value:
            module_name = self.module_name(row)
            interface_name = self.interface_name(row)
            return self.expect_data_dict[module_name][interface_name][value]
        else:
            return None


    def get_sql_type(self,row):
        value = self.__get_cell_data(SQLTYPE,row)
        if value is None:
            return None
        elif value:
            return value.lower()
        else:
            return None


    def sql_sentence(self,row):
        value = self.__get_cell_data(SQLSENTENCE,row)
        if value is None:
            return None
        elif value:
            module_name = self.module_name(row)
            interface_name = self.interface_name(row)
            return self.sql_data_dict[module_name][interface_name][value]
        else:
            return None


    def update_key(self,row):
        value = self.__get_cell_data(UPDATEKEY,row)
        if value is None:
            return None
        elif value:
            return value
        else:
            return None


    def get_data(self):
        list_data = []
        for row in range(2,self.ws.max_row+1):
            module_name = self.module_name(row)
            interface_name = self.interface_name(row)
            case_title = self.case_title(row)
            case_level = self.case_level(row)
            case_method = self.case_method(row)
            case_url = self.case_url(row)
            case_mime = self.case_mime(row)
            case_data = self.case_data(row)
            expect_data = self.expect_data(row)
            sql_type = self.get_sql_type(row)
            sql_sentence = self.sql_sentence(row)
            update_key = self.update_key(row)
            list_data.append([module_name,interface_name,case_title,case_level,case_method,case_url,case_mime,case_data,expect_data,sql_type,sql_sentence,update_key])
        else:
            return list_data


if __name__ == '__main__':
    read_excel = ReadExcel()
    print(read_excel.case_mime(15))









